Re: Unix Philosophers Please!

2001-10-31 Thread Chad Ziccardi

On Wed, 31 Oct 2001, Nicpon, John wrote:

> Please specifically define where data goes that is sent to /dev/null

To boldy go where no Data has returned from before?

-- 
Chad Ziccardi, Professional Slacker  [EMAIL PROTECTED]
"Some cause happiness wherever they go; others whenever they go."


To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Unix Philosophers Please!

2001-10-31 Thread Josef Karthauser

On Wed, Oct 31, 2001 at 05:20:33PM -0800, Lamont Granquist wrote:
> 
> 
> On Wed, 31 Oct 2001, Stephen Montgomery-Smith wrote:
> > > "Nicpon, John" wrote:
> > >
> > > Please specifically define where data goes that is sent to /dev/null
> >
> > Answer 1.  Data is not like energy.  There is no "conservation of data"
> > law.  So the data simply "disappears".
> 
> Doesn't thermodynamics second law actually imply that data has to
> disappear and that with the heat death of the universe data will be at a
> minimum?  For meaningful data to exist there needs to be order, while the
> 2nd law requires that systems evolve to less ordered states.

Maybe, but the second law of thermodynamics is incorrect so who knows?

Joe

 PGP signature


Re: pmap_collect() and PG_UNMANAGED

2001-10-31 Thread David Xu


- Original Message - 
From: "Peter Wemm" <[EMAIL PROTECTED]>
To: "David Xu" <[EMAIL PROTECTED]>
Cc: <[EMAIL PROTECTED]>
Sent: Thursday, November 01, 2001 9:43 AM
Subject: Re: pmap_collect() and PG_UNMANAGED 


> "David Xu" wrote:
> > This is a multi-part message in MIME format.
> > 
> > --=_NextPart_000_000C_01C162B1.0ECE7770
> > Content-Type: text/plain;
> > charset="gb2312"
> > Content-Transfer-Encoding: quoted-printable
> > 
> > Hi,
> > 
> >   is there any reason why pmap_collect() in /sys/i386/i386/pmap.c does =
> > not
> >   check PG_UNMANAGED flag? unmanaged page does not have pv_entry =
> > associated,
> >   so call pmap_remove_all() has side effect, PG_MAPPED and PG_WRITEABLE =
> > are=20
> >   roughly cleared.
> > 
> > --
> > David Xu
> 
> Did you have something like this in mind?
> 
> @@ -1729,7 +1729,7 @@
> for(i = 0; i < vm_page_array_size; i++) {
> m = &vm_page_array[i];
> if (m->wire_count || m->hold_count || m->busy ||
> -   (m->flags & PG_BUSY))
> +   (m->flags & (PG_BUSY | PG_UNMANAGED)))
> continue;
> pmap_remove_all(m);
> }
> 

Yes, I have changed and tested it yesterday, I have pushed a memory hog program into 
system, run it about half an hour, almost every program was swapped out, still without
cause any problem, it seems it is safe to add this flag.

> BTW; please stop posting MIME/HTML onto mailing lists.
> 
Sorry, my MS Outlook express sucks, I will replace it with better one!

> Cheers,
> -Peter
> --
> Peter Wemm - [EMAIL PROTECTED]; [EMAIL PROTECTED]; [EMAIL PROTECTED]
> "All of this is for nothing if we don't go to the stars" - JMS/B5

--
David Xu



To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: pmap_collect() and PG_UNMANAGED

2001-10-31 Thread Peter Wemm

"David Xu" wrote:
> This is a multi-part message in MIME format.
> 
> --=_NextPart_000_000C_01C162B1.0ECE7770
> Content-Type: text/plain;
>   charset="gb2312"
> Content-Transfer-Encoding: quoted-printable
> 
> Hi,
> 
>   is there any reason why pmap_collect() in /sys/i386/i386/pmap.c does =
> not
>   check PG_UNMANAGED flag? unmanaged page does not have pv_entry =
> associated,
>   so call pmap_remove_all() has side effect, PG_MAPPED and PG_WRITEABLE =
> are=20
>   roughly cleared.
> 
> --
> David Xu

Did you have something like this in mind?

@@ -1729,7 +1729,7 @@
for(i = 0; i < vm_page_array_size; i++) {
m = &vm_page_array[i];
if (m->wire_count || m->hold_count || m->busy ||
-   (m->flags & PG_BUSY))
+   (m->flags & (PG_BUSY | PG_UNMANAGED)))
continue;
pmap_remove_all(m);
}

BTW; please stop posting MIME/HTML onto mailing lists.

Cheers,
-Peter
--
Peter Wemm - [EMAIL PROTECTED]; [EMAIL PROTECTED]; [EMAIL PROTECTED]
"All of this is for nothing if we don't go to the stars" - JMS/B5


To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Unix Philosophers Please!

2001-10-31 Thread Jim Bryant

Lamont Granquist wrote:

> 
> On Wed, 31 Oct 2001, Stephen Montgomery-Smith wrote:
> 
>>>"Nicpon, John" wrote:
>>>
>>>Please specifically define where data goes that is sent to /dev/null
>>>
>>Answer 1.  Data is not like energy.  There is no "conservation of data"
>>law.  So the data simply "disappears".
>>
> 
> Doesn't thermodynamics second law actually imply that data has to
> disappear and that with the heat death of the universe data will be at a
> minimum?  For meaningful data to exist there needs to be order, while the
> 2nd law requires that systems evolve to less ordered states.
> 
> The only uncertainty about this that I've got is that random systems can
> actually be very dense with data.  Think about a compressed and encrypted
> file, which should be indistinguishable from /dev/random output.
> 
> I guess the difference between those two is that there is only a single
> state which validly represents the comprssed and encrypted file.  On the
> other hand there may be many states which represent the valid output of
> /dev/random (of course you only obtain one of these states).  Since there
> are more states for /dev/random there is more entropy (and actually the
> compressed file having only one valid state would have minimal entropy).
> 
> Did I get that right?  My thermodynamics and info theory are a little
> rusty...
> 
> Contribute to the Heat Death of the Universe!  pipe everything to /dev/null!


Nah, you have it all wrong...

The data goes into a wormhole, much similar to the one that splits up your pairs of 
socks in the dryer, and the data wormhole simply 
sucks it into another universe.

No need to worry about the collapse of our universe because of /dev/null

BUT...Piping all that data to /dev/null MAY destroy the universe that keeps sending 
flying saucers to the houses of Art Bell fans in 
places like Lockjaw, Kentucky or Moose Turd, Montana...


jim
-- 
  ET has one helluva sense of humor!
 He's always anal-probing right-wing schizos!
-
POWER TO THE PEOPLE!
-
"Religious fundamentalism is the biggest threat to
 international security that exists today."
  United Nations Secretary General B.B.Ghali, 1995


_
Do You Yahoo!?
Get your free @yahoo.com address at http://mail.yahoo.com


To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Unix Philosophers Please!

2001-10-31 Thread Lamont Granquist



On Wed, 31 Oct 2001, Stephen Montgomery-Smith wrote:
> > "Nicpon, John" wrote:
> >
> > Please specifically define where data goes that is sent to /dev/null
>
> Answer 1.  Data is not like energy.  There is no "conservation of data"
> law.  So the data simply "disappears".

Doesn't thermodynamics second law actually imply that data has to
disappear and that with the heat death of the universe data will be at a
minimum?  For meaningful data to exist there needs to be order, while the
2nd law requires that systems evolve to less ordered states.

The only uncertainty about this that I've got is that random systems can
actually be very dense with data.  Think about a compressed and encrypted
file, which should be indistinguishable from /dev/random output.

I guess the difference between those two is that there is only a single
state which validly represents the comprssed and encrypted file.  On the
other hand there may be many states which represent the valid output of
/dev/random (of course you only obtain one of these states).  Since there
are more states for /dev/random there is more entropy (and actually the
compressed file having only one valid state would have minimal entropy).

Did I get that right?  My thermodynamics and info theory are a little
rusty...

Contribute to the Heat Death of the Universe!  pipe everything to /dev/null!


To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



MFS "inside" the Kernel

2001-10-31 Thread Eduardo B . Fonseca

Hello Guys,

I would like to know how do I put a MFS partition "inside" the kernel? I've 
seen some people mention this, but no "HOWTOs"... I've tried to use the 
"write_mfs_in_kernel" program, but when I try to boot, I get "BTX Halted" 
error. Please, help me!

Thanks!

Eduardo.

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



pmap_collect() and PG_UNMANAGED

2001-10-31 Thread David Xu



Hi,  is there any reason why pmap_collect() in 
/sys/i386/i386/pmap.c does not  check PG_UNMANAGED flag? unmanaged page 
does not have pv_entry associated,  so call pmap_remove_all() has side 
effect, PG_MAPPED and PG_WRITEABLE are   roughly 
cleared.--
David Xu
 


Re: CVS: connection refused

2001-10-31 Thread Josef Karthauser

On Wed, Oct 31, 2001 at 03:13:23PM -0800, Hiten Pandya wrote:
> hi all,
> i have been trying to connect to the FreeBSD Anonymous
> CVS Server.. and it always keeps on saying no to me...
> could some guide me thru this please..
> 
> thanks...
> 
> error:
> cvs [login aborted]: connect to
> anoncvs.FreeBSD.org:2401 failed: Connection refused

Hiten,

The anoncvs server is down at the moment.  There's been a discussion
about it recently on one of the other lists, although I can't remember
which one, maybe hubs@ ?  (Someone announced an unofficial one that
could be used in the meantime).

Joe

 PGP signature


CVS: connection refused

2001-10-31 Thread Hiten Pandya

hi all,
i have been trying to connect to the FreeBSD Anonymous
CVS Server.. and it always keeps on saying no to me...
could some guide me thru this please..

thanks...

error:
cvs [login aborted]: connect to
anoncvs.FreeBSD.org:2401 failed: Connection refused


-
regards,
hiten pandya

__
Do You Yahoo!?
Make a great connection at Yahoo! Personals.
http://personals.yahoo.com

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Unix Philosophers Please!

2001-10-31 Thread Wilko Bulte

On Wed, Oct 31, 2001 at 03:08:38PM -0700, Drew Eckhardt wrote:
> In message <[EMAIL PROTECTED]>, Joh
> [EMAIL PROTECTED] writes:
> >What question are you _really_ trying to ask?
> 
> What is the sound of one hand clapping?

Can this go to -chat please??

-- 
|   / o / /_  _ email:  [EMAIL PROTECTED]
|/|/ / / /(  (_)  Bulte Arnhem, The Netherlands 

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Unix Philosophers Please!

2001-10-31 Thread Terry Lambert

Stephen Montgomery-Smith wrote:
> Answer 2.  All the data goes into another dimension, and comes out of
> /dev/random.

That would be so funny... I cat /dev/random, and I get your
files, as you delete them.  8-).

-- Terry

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Unix Philosophers Please!

2001-10-31 Thread Stephen Montgomery-Smith

> "Nicpon, John" wrote:
> 
> Please specifically define where data goes that is sent to /dev/null

Answer 1.  Data is not like energy.  There is no "conservation of data"
law.  So the data simply "disappears".

Answer 2.  All the data goes into another dimension, and comes out of
/dev/random.


-- 
Stephen Montgomery-Smith
[EMAIL PROTECTED]
http://www.math.missouri.edu/~stephen

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Unix Philosophers Please!

2001-10-31 Thread Josef Grosch

On Wed, Oct 31, 2001 at 03:08:38PM -0700, Drew Eckhardt wrote:
> In message <[EMAIL PROTECTED]>, Joh
> [EMAIL PROTECTED] writes:
> >What question are you _really_ trying to ask?
> 
> What is the sound of one hand clapping?

If a bit falls into the bit bucket and signal is not raised does it make a
sound? 


Next week: Why do hot dogs come in packages of 12 and hot dog buns in
packages of 8? 

Extra credit: Why are all the good ones taken? Is this a demo of how
supply side economics is not working?


Josef

-- 
Josef Grosch   | Another day closer to a | FreeBSD 4.4
[EMAIL PROTECTED] |   Micro$oft free world  | www.bafug.org


To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Unix Philosophers Please!

2001-10-31 Thread Drew Eckhardt

In message <[EMAIL PROTECTED]>, Joh
[EMAIL PROTECTED] writes:
>What question are you _really_ trying to ask?

What is the sound of one hand clapping?


To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Unix Philosophers Please!

2001-10-31 Thread Louis A. Mamakos

> 
> > "Nicpon, John" wrote:
> > 
> > Please specifically define where data goes that is sent to /dev/null
> 
> to the place where no data ever came back.
> 

..on those "blank" tapes on which you should be backing up the data 
you do care about.

..to help fight the secret, hidden war against entropy.



To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Unix Philosophers Please!

2001-10-31 Thread Mathieu Arnold


> "Nicpon, John" wrote:
> 
> Please specifically define where data goes that is sent to /dev/null

to the place where no data ever came back.

-- 
Mathieu Arnold

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Unix Philosophers Please!

2001-10-31 Thread Jim Bryant

It's similar to the space/time wormhole that appears in your clothes dryer, and 
randomly sucks out only one sock out of every pair 
into a parallel universe.

Somewhere, there is a universe made up of nothing but odd socks, where they each lead 
a very happy odd-sockish singular life.

I assume that input to /dev/null goes to a parallel universe consisting entirely of 
unwanted, wayward data.

Nicpon, John wrote:

> Where does data go when it dies?
> 
> -Original Message-
> From: Brian Reichert [mailto:[EMAIL PROTECTED]]
> Sent: Wednesday, October 31, 2001 3:08 PM
> To: Nicpon, John
> Cc: [EMAIL PROTECTED]
> Subject: Re: Unix Philosophers Please!
> 
> 
> On Wed, Oct 31, 2001 at 03:02:59PM -0600, Nicpon, John wrote:
> 
>>Please specifically define where data goes that is sent to /dev/null
>>
> 
> How 'specific' are you trying to get?  /dev/null is a pseudo-device
> to which writes never fail.
> 
> What question are you _really_ trying to ask?
> 
> 

jim
-- 
  ET has one helluva sense of humor!
 He's always anal-probing right-wing schizos!
-
POWER TO THE PEOPLE!
-
"Religious fundamentalism is the biggest threat to
 international security that exists today."
  United Nations Secretary General B.B.Ghali, 1995


_
Do You Yahoo!?
Get your free @yahoo.com address at http://mail.yahoo.com


To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Unix Philosophers Please!

2001-10-31 Thread Bakul Shah

> Please specifically define where data goes that is sent to /dev/null

The same place where /dev/random gets its data from.  Unless
your computer is owned by gummint, in which case FBI gets it
as you have to keep a copy of all output.

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



RE: Unix Philosophers Please!

2001-10-31 Thread Nicpon, John

Where does data go when it dies?

-Original Message-
From: Brian Reichert [mailto:[EMAIL PROTECTED]]
Sent: Wednesday, October 31, 2001 3:08 PM
To: Nicpon, John
Cc: [EMAIL PROTECTED]
Subject: Re: Unix Philosophers Please!


On Wed, Oct 31, 2001 at 03:02:59PM -0600, Nicpon, John wrote:
> Please specifically define where data goes that is sent to /dev/null

How 'specific' are you trying to get?  /dev/null is a pseudo-device
to which writes never fail.

What question are you _really_ trying to ask?

-- 
Brian 'you Bastard' Reichert<[EMAIL PROTECTED]>
37 Crystal Ave. #303Daytime number: (603) 434-6842
Derry NH 03038-1713 USA Intel architecture: the
left-hand path

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Unix Philosophers Please!

2001-10-31 Thread Jim Bryant

Nicpon, John wrote:

> Please specifically define where data goes that is sent to /dev/null
> 


Without actually looking at the code, the generic definition of /dev/null goes 
something to the effect of:



open /dev/null

while(1)
{
select on /dev/null
read byte from /dev/null
}


So basically, it just reads what is there, but does absolutely nothing with it.


jim
-- 
  ET has one helluva sense of humor!
 He's always anal-probing right-wing schizos!
-
POWER TO THE PEOPLE!
-
"Religious fundamentalism is the biggest threat to
 international security that exists today."
  United Nations Secretary General B.B.Ghali, 1995


_
Do You Yahoo!?
Get your free @yahoo.com address at http://mail.yahoo.com


To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Unix Philosophers Please!

2001-10-31 Thread Geoff Mohler



On Wed, 31 Oct 2001, Brian Reichert wrote:

> On Wed, Oct 31, 2001 at 03:02:59PM -0600, Nicpon, John wrote:
> > Please specifically define where data goes that is sent to /dev/null
> 
> How 'specific' are you trying to get?  /dev/null is a pseudo-device
> to which writes never fail.
> 
> What question are you _really_ trying to ask?
> 
> -- 
> Brian 'you Bastard' Reichert  <[EMAIL PROTECTED]>
> 37 Crystal Ave. #303  Daytime number: (603) 434-6842
> Derry NH 03038-1713 USA   Intel architecture: the left-hand path
> 
> To Unsubscribe: send mail to [EMAIL PROTECTED]
> with "unsubscribe freebsd-hackers" in the body of the message
> 

---
Geoff Mohler


To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Unix Philosophers Please!

2001-10-31 Thread Terry Lambert

> "Nicpon, John" wrote:
> 
> Please specifically define where data goes that is sent to /dev/null

The bit bucket.

You won't have to empty the one in your machine until the year
2038, which we assume someone will come up with a way of recyling
the used bits by then (or just compressing them into bus benches).

-- Terry

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Unix Philosophers Please!

2001-10-31 Thread Brian Reichert

On Wed, Oct 31, 2001 at 03:02:59PM -0600, Nicpon, John wrote:
> Please specifically define where data goes that is sent to /dev/null

How 'specific' are you trying to get?  /dev/null is a pseudo-device
to which writes never fail.

What question are you _really_ trying to ask?

-- 
Brian 'you Bastard' Reichert<[EMAIL PROTECTED]>
37 Crystal Ave. #303Daytime number: (603) 434-6842
Derry NH 03038-1713 USA Intel architecture: the left-hand path

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Unix Philosophers Please!

2001-10-31 Thread Nicpon, John



Please specifically 
define where data goes that is sent to 
/dev/null


test!

2001-10-31 Thread ebf

just testing!
thanks!OM
Eduardo.


To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



ssh forwarding

2001-10-31 Thread Martin Vana

hi,
I've got a problem with ssh forwarding. I wont to be able to run a service
which has one stable port to communicate (411) and then starts to
create another connections on random ports below 1. Forwarding
just one port is throug our firewall was easy. But how to forward
whole 1 ports?
can you help me?
thank you

Some info about firewall only 20/21/22/80/ and some other ports are allowed
non above 1000



To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Driver help

2001-10-31 Thread Wilko Bulte

On Wed, Oct 31, 2001 at 10:37:47AM -0800, Matthew Jacob wrote:
> "dumb" is relative and fungible.

Sure..

> It's a tradeoff between doing the connection management in firmware (as with
> the QLogic) or in the Kernel (as with Tachyon products mostly). It depends on
> whom you believe ultimately does a better job.

Well, I generally would like to put my money on the firmware. This assumes
(as always..) good firmware.

> Doing it in firmware allows the driver writer to manage the ULP stuff a lot
> better because you're not so distracted by the low level ruckus.



> Doing it in the kernel allows you to avoid all those nagging and persistent
> questions of "why the hell did the f/w do/say/barf&&turn-left-against-a-red
> *that*?"

But it tends to produce horrible drivers if you are not very careful.
I remember a WD33C93 driver here.. 

> On Wed, 31 Oct 2001, Wilko Bulte wrote:
> 
> > On Wed, Oct 31, 2001 at 09:49:19AM -0800, Matthew Jacob wrote:
> > 
> > That is probably what we call the Jaguar in-house. It is (IIRC) a
> > dumb adapter, there is a Tachyon on it for sure.
> > 
> > Wilko
---end of quoted text---

-- 
|   / o / /_  _ email:  [EMAIL PROTECTED]
|/|/ / / /(  (_)  Bulte Arnhem, The Netherlands 

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Driver help

2001-10-31 Thread Terry Lambert

Matthew Jacob wrote:
> 
> "dumb" is relative and fungible.
> 
> It's a tradeoff between doing the connection management in firmware (as with
> the QLogic) or in the Kernel (as with Tachyon products mostly). It depends on
> whom you believe ultimately does a better job.
> 
> Doing it in firmware allows the driver writer to manage the ULP stuff a lot
> better because you're not so distracted by the low level ruckus.
> 
> Doing it in the kernel allows you to avoid all those nagging and persistent
> questions of "why the hell did the f/w do/say/barf&&turn-left-against-a-red
> *that*?"

I'm personally a "firm" believer in having the card do the
work so as to avoid the unnecessary bus transfers from the
kernel doing the work.

Alfred and Eric Melville both have incredibly funny anecdotes
about Windows machines without GL accelerators configured as
servers, and with GL screen savers which eat most of the CPU
away from server applications...

-- Terry

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Driver help

2001-10-31 Thread Matthew Jacob


"dumb" is relative and fungible.

It's a tradeoff between doing the connection management in firmware (as with
the QLogic) or in the Kernel (as with Tachyon products mostly). It depends on
whom you believe ultimately does a better job.

Doing it in firmware allows the driver writer to manage the ULP stuff a lot
better because you're not so distracted by the low level ruckus.

Doing it in the kernel allows you to avoid all those nagging and persistent
questions of "why the hell did the f/w do/say/barf&&turn-left-against-a-red
*that*?"

-matt


On Wed, 31 Oct 2001, Wilko Bulte wrote:

> On Wed, Oct 31, 2001 at 09:49:19AM -0800, Matthew Jacob wrote:
> 
> That is probably what we call the Jaguar in-house. It is (IIRC) a
> dumb adapter, there is a Tachyon on it for sure.
> 
> Wilko


To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Driver help

2001-10-31 Thread Wilko Bulte

On Wed, Oct 31, 2001 at 09:49:19AM -0800, Matthew Jacob wrote:

That is probably what we call the Jaguar in-house. It is (IIRC) a
dumb adapter, there is a Tachyon on it for sure.

Wilko

> Yes, well, there is something Linux called the Compaq Fibre Channel Driver,
> and it's not QLogic based- nor is it Emulex based- I believe it's Tachyon-
> lite.
> 
> On Wed, 31 Oct 2001, Wilko Bulte wrote:
> 
> > On Wed, Oct 31, 2001 at 08:08:42AM +0100, Wilko Bulte wrote:
> > > On Tue, Oct 30, 2001 at 06:04:16PM -0600, Nick Rogness wrote:
> > > 
> > > There is the isp(4) driver, by Matt Jacob, that supports Qlogic 
> > > FC HBAs.
> > 
> > Further clarifyin this: CPQ use QL2200 for use with Linux. 
> > CPQ KGPSA are Emulex LP[78]000, as used on Tru64,OVMS etc.
> > 
> > > 
> > > > The company I work for is willing to pay for someone to write a Compaq
> > > > Fibe Channel driver for FreeBSD.  Please write me personally if you are
> > > > interested.
> > > > 
> > > > Nick Rogness <[EMAIL PROTECTED]>
> > > >  - Keep on Routing in a Free World...
> > > >   "FreeBSD: The Power to Serve!"
> > > > 
> > > > 
> > > > 
> > > > 
> > > > To Unsubscribe: send mail to [EMAIL PROTECTED]
> > > > with "unsubscribe freebsd-hackers" in the body of the message
> > > ---end of quoted text---
> > > 
> > > -- 
> > > |   / o / /_  _   email:  [EMAIL PROTECTED]
> > > |/|/ / / /(  (_)  Bulte   Arnhem, The Netherlands 
> > > 
> > > To Unsubscribe: send mail to [EMAIL PROTECTED]
> > > with "unsubscribe freebsd-hackers" in the body of the message
> > ---end of quoted text---
> > 
> > -- 
> > |   / o / /_  _ email:  [EMAIL PROTECTED]
> > |/|/ / / /(  (_)  Bulte Arnhem, The Netherlands 
> > 
> > To Unsubscribe: send mail to [EMAIL PROTECTED]
> > with "unsubscribe freebsd-hackers" in the body of the message
> > 
---end of quoted text---

-- 
|   / o / /_  _ email:  [EMAIL PROTECTED]
|/|/ / / /(  (_)  Bulte Arnhem, The Netherlands 

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Driver help

2001-10-31 Thread Matthew Jacob


Yes, well, there is something Linux called the Compaq Fibre Channel Driver,
and it's not QLogic based- nor is it Emulex based- I believe it's Tachyon-
lite.

On Wed, 31 Oct 2001, Wilko Bulte wrote:

> On Wed, Oct 31, 2001 at 08:08:42AM +0100, Wilko Bulte wrote:
> > On Tue, Oct 30, 2001 at 06:04:16PM -0600, Nick Rogness wrote:
> > 
> > There is the isp(4) driver, by Matt Jacob, that supports Qlogic 
> > FC HBAs.
> 
> Further clarifyin this: CPQ use QL2200 for use with Linux. 
> CPQ KGPSA are Emulex LP[78]000, as used on Tru64,OVMS etc.
> 
> > 
> > > The company I work for is willing to pay for someone to write a Compaq
> > > Fibe Channel driver for FreeBSD.  Please write me personally if you are
> > > interested.
> > > 
> > > Nick Rogness <[EMAIL PROTECTED]>
> > >  - Keep on Routing in a Free World...
> > >   "FreeBSD: The Power to Serve!"
> > > 
> > > 
> > > 
> > > 
> > > To Unsubscribe: send mail to [EMAIL PROTECTED]
> > > with "unsubscribe freebsd-hackers" in the body of the message
> > ---end of quoted text---
> > 
> > -- 
> > |   / o / /_  _ email:  [EMAIL PROTECTED]
> > |/|/ / / /(  (_)  Bulte Arnhem, The Netherlands 
> > 
> > To Unsubscribe: send mail to [EMAIL PROTECTED]
> > with "unsubscribe freebsd-hackers" in the body of the message
> ---end of quoted text---
> 
> -- 
> |   / o / /_  _   email:  [EMAIL PROTECTED]
> |/|/ / / /(  (_)  Bulte   Arnhem, The Netherlands 
> 
> To Unsubscribe: send mail to [EMAIL PROTECTED]
> with "unsubscribe freebsd-hackers" in the body of the message
> 


To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



RE: ACPI CA updated

2001-10-31 Thread Doug Rabson

On Wed, 31 Oct 2001, Grover, Andrew wrote:

> > From: Doug Rabson [mailto:[EMAIL PROTECTED]]
> > This doesn't appear to fix the 64bit alignment problems which
> > we had while
> > trying to use the code on ia64. Any news on when/whether
> > Intel will accept
> > our 64bit patches?
>
> Our next release will include a fix for this.

Good news, thanks!

-- 
Doug Rabson Mail:  [EMAIL PROTECTED]
Phone: +44 20 8348 6160



To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Interesting OS research project

2001-10-31 Thread Rayson Ho

http://www.research.ibm.com/K42/

Rayson





__
Do You Yahoo!?
Make a great connection at Yahoo! Personals.
http://personals.yahoo.com

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



RE: ACPI CA updated

2001-10-31 Thread Grover, Andrew

> From: Doug Rabson [mailto:[EMAIL PROTECTED]]
> This doesn't appear to fix the 64bit alignment problems which 
> we had while
> trying to use the code on ia64. Any news on when/whether 
> Intel will accept
> our 64bit patches?

Our next release will include a fix for this.

Regards -- Andy

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Simple pthread question

2001-10-31 Thread Stephen Montgomery-Smith

Arjan Knepper wrote:
> 
> How do I suspend one particular thread without suspending the whole process?
> I can not use sleep or usleep can I?
> 

Also, if you do 

apropos pthread

you will see listed a whole bunch of functions, some of which may be more
suitable for you, depending upon your particular problem, for example

pthread_cond_timedwait

-- 

Stephen Montgomery-Smith
[EMAIL PROTECTED]
http://www.math.missouri.edu/~stephen

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Simple pthread question

2001-10-31 Thread Sansonetti Laurent

On Wed, 2001-10-31 at 08:26, Arjan Knepper wrote:
> How do I suspend one particular thread without suspending the whole process?
> I can not use sleep or usleep can I?

You can use them, since they use nanosleep() which is I think
re-entrant.

If you are using digital unix pthreads implementation, there is
something like pthread_delay_np() which you can still use.

Hope that helps.

> 
> TIA
> Arjan
> 
> 
> To Unsubscribe: send mail to [EMAIL PROTECTED]
> with "unsubscribe freebsd-hackers" in the body of the message
-- 

--
Sansonetti Laurent - http://lrz.linuxbe.org



To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Simple pthread question

2001-10-31 Thread Stephen Montgomery-Smith

I have successfully used sleep in this situation.  I wanted a process that
activated every hour (it did some "garbage collection"), so it went something
like

while (1) {
  sleep(3600);
  do_stuff();
}

and the other threads worked fine.


Arjan Knepper wrote:
> 
> How do I suspend one particular thread without suspending the whole process?
> I can not use sleep or usleep can I?
> 
> TIA
> Arjan
> 
> To Unsubscribe: send mail to [EMAIL PROTECTED]
> with "unsubscribe freebsd-hackers" in the body of the message

-- 

Stephen Montgomery-Smith
[EMAIL PROTECTED]
http://www.math.missouri.edu/~stephen

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Driver help

2001-10-31 Thread Wilko Bulte

On Wed, Oct 31, 2001 at 08:08:42AM +0100, Wilko Bulte wrote:
> On Tue, Oct 30, 2001 at 06:04:16PM -0600, Nick Rogness wrote:
> 
> There is the isp(4) driver, by Matt Jacob, that supports Qlogic 
> FC HBAs.

Further clarifyin this: CPQ use QL2200 for use with Linux. 
CPQ KGPSA are Emulex LP[78]000, as used on Tru64,OVMS etc.

> 
> > The company I work for is willing to pay for someone to write a Compaq
> > Fibe Channel driver for FreeBSD.  Please write me personally if you are
> > interested.
> > 
> > Nick Rogness <[EMAIL PROTECTED]>
> >  - Keep on Routing in a Free World...
> >   "FreeBSD: The Power to Serve!"
> > 
> > 
> > 
> > 
> > To Unsubscribe: send mail to [EMAIL PROTECTED]
> > with "unsubscribe freebsd-hackers" in the body of the message
> ---end of quoted text---
> 
> -- 
> |   / o / /_  _   email:  [EMAIL PROTECTED]
> |/|/ / / /(  (_)  Bulte   Arnhem, The Netherlands 
> 
> To Unsubscribe: send mail to [EMAIL PROTECTED]
> with "unsubscribe freebsd-hackers" in the body of the message
---end of quoted text---

-- 
|   / o / /_  _ email:  [EMAIL PROTECTED]
|/|/ / / /(  (_)  Bulte Arnhem, The Netherlands 

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: pxe booting problem

2001-10-31 Thread Henri Michelon

Le Mercredi 31 Octobre 2001 12:49, vous avez écrit :
> Henri,
>
> FYI - this is my dhcpd.conf.  I didn't have to enable
> a lot of the options you had in yours:
>
>

My dhcpd.conf is a 'pxe' generic config. I used it with FreBSD pxeboot, 
pxelinux, pxegrub, bpbatch and 3COM .pxe files.
Some PXE boot loaders need some options, others not, and this config works 
with all pxe clients I have tested.

Henri.

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Changing syscalls numbers

2001-10-31 Thread Nickolay A.Kritsky

Hello Evan,

Wednesday, October 31, 2001, 2:41:57 PM, you wrote:

ES> Did you type make init_sysent.c, after editing syscalls.master?

ES> - Evan

No. I relied on "make buildkernel". I will try this now.

Maxime Henrion <[EMAIL PROTECTED]> wrote :

MH> /usr/src/sys/kern/makesyscalls.sh syscalls.master

As far as I understand Makefile format, it is part of "make
init_sysent.c"

Thank you for your help

;---
; NKritsky
; SysAdmin InternetHelp.Ru
; http://www.internethelp.ru
; mailto:[EMAIL PROTECTED]



To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: pxe booting problem

2001-10-31 Thread Paul Jansen

Henri,

FYI - this is my dhcpd.conf.  I didn't have to enable
a lot of the options you had in yours:

"
# dhcpd.conf

# define new options
option nfs-swap code 128 = string;
option swap-size code 129 = integer 32;

# option definitions common to all supported
networks...
option domain-name "jansen.org";
option domain-name-servers 203.57.68.5, 203.57.68.5;

ddns-update-style ad-hoc;

default-lease-time 600;
max-lease-time 7200;

authoritative;

# Use this to send dhcp log messages to a different
log file (you also
# have to hack syslog.conf to complete the
redirection).
log-facility local7;

subnet 192.168.0.0 netmask 255.255.255.0 {
  range dynamic-bootp 192.168.0.13 192.168.0.20;
  use-host-decl-names on;
  option routers 192.168.0.8;
  option broadcast-address 192.168.0.255;
  if substring (option vendor-class-identifier,0,9) =
"PXEClient" {
filename "pxeboot"
  }
  option root-path "192.168.0.1:/diskless";
  option nfs-swap "192.168.0.1:/nfs-swap";
  option swap-size 10240;
}

host host12 {
   hardware ethernet 00:02:55:70:86:e8;
  fixed-address host12.jansen.org;
}
"

I found pxeboot in /boot on my 4.4r system and after
the  config file for ISC DHCPDv3 is in place and DHCPD
is started things work great.  I needed to make sure
the /tftpboot/boot/loader.rc existed and that I copied
my diskless kernel to /tftpboot/kernel.
Thanks for your suggestions.

Paul

 --- Henri Michelon <[EMAIL PROTECTED]>
wrote: > Le Mardi 30 Octobre 2001 14:30, vous avez
écrit :
> > I posted some of this info last friday but haven't
> had
> > any responses.  I'm hoping someone out there knows
> > what the problem is.  Here's the details:
> >
> > I saw Alfred Perlsteins page on how to setup
> > FreeBSD installs unsing PXE.
> > The problem I'm having now is when I follow
> Alfred's
> > directions to create the PXE loader (using 4.4R)
> It
> > bombs out.  It's my understanding the I just need
> to
> > stick 'pxeldr' into the root of the TFTP server
> > directory and tell the machine to execute this by
> > specifying it as the boot file in the DHCP
> > configuration.  I also understand that I have to
> > create a subdirectory called 'boot' under the TFTP
> > root directory with the file 'loader.rc' in it. 
> Can
> > someone verify if this is the case?
> > Alfred's instructions can be found here:
> > http://people.freebsd.org/~alfred/pxe/
> >
> > This is the console output that insues when I try
> and
> > build pxeldr as per Alfred's instructions:
> >
> 
> 
> You can find pxeboot (instead of pxeldr) if /boot.
> Just copy it into /tftpboot, and add the following
> in the dhcpd config file 
> (for isc-dhcp version 3):
> 
> option space PXE;
> option PXE.mtftp-ipcode 1 = ip-address;
> option PXE.mtftp-cport code 2 = unsigned integer 16;
> option PXE.mtftp-sport code 3 = unsigned integer 16;
> option PXE.mtftp-tmout code 4 = unsigned integer 8;
> option PXE.mtftp-delay code 5 = unsigned integer 8;
> 
> class "pxeclients" {
> match if substring (option
> vendor-class-identifier, 0, 9) = 
> "PXEClient";
> option vendor-class-identifier "PXEClient";
> option PXE.mtftp-ip 0.0.0.0;
> vendor-option-space PXE;
> next-server X.X.X.X;
> server-name "X.X.X.X";
> server-identifier X.X.X.X;
>  
> option root-path "/path/to/FreeBSD/CDROM";
>  
> filename "pxeboot";
> }
> 
> where X.X.X.X is the IP address of the tftp boot
> server.
> 
> Henri. 

http://briefcase.yahoo.com.au - Yahoo! Briefcase
- Manage your files online.

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: ACPI CA updated

2001-10-31 Thread Doug Rabson

On Tue, 30 Oct 2001, Mike Smith wrote:

>
> I've just updated the ACPI CA subsystem to the Intel 20011018 snapshot.
>
> This primarily fixes a couple of bugs in the ACPI interpreter; see the
> changelog at
>
>   http://developer.intel.com/technology/iapc/acpi/downloads/CHANGES.txt
>
> for full details.

This doesn't appear to fix the 64bit alignment problems which we had while
trying to use the code on ia64. Any news on when/whether Intel will accept
our 64bit patches?

-- 
Doug Rabson Mail:  [EMAIL PROTECTED]
Phone: +44 20 8348 6160



To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Changing syscalls numbers

2001-10-31 Thread Maxime Henrion

Nickolay A.Kritsky wrote:
>   Hi, freebsd-hackers.
> 
> Recently I was trying to change some syscalls numbers (i.e. syscall
> exit would have number 5 and syscall open would have number 1).
> My thought was, that for that operation one must edit file
> /usr/src/sys/kern/syscalls.master and remake world. I edited the file
> named above, rebooted in single-user mode, and ran "make buildworld &&
> make buildkernel && make installkernel && make installworld".
> Everything seems to be OK, new kernel has been built and installed (I
> think it is `new', because /kernel has the creation date of "make
> installkernel" and diff says it differs from /kernel.old ), but
> mov eax,1
> push eax
> int 80h
> 
> still performs exit.
> 
> Could you point me, what wrong assumptions/steps have I done?
> Any help is very good.

/usr/src/sys/kern/makesyscalls.sh syscalls.master

Maxime
-- 
Don't be fooled by cheap finnish imitations ; BSD is the One True Code

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



RE: pxe booting problem

2001-10-31 Thread Paul Jansen

I looked in /boot on my 4.4R system and there was a
'pxeboot' file there.  I've since modded my ISCv3
DHCPD.conf file to serve this file out to machines
(after creating /tftpboot/boot/loader.rc) and it works
great. Next step will be to test getting this to work
using reservations from the MS DHCP server on our LAN
(pretty sure this will work) and people will be able
to boot diskless FreeBSD by pressing F12 at boot up.
Thanks fo your help John.

Paul

 --- John Baldwin <[EMAIL PROTECTED]> wrote: > 
> On 30-Oct-01 Paul Jansen wrote:
> > I posted some of this info last friday but haven't
> had
> > any responses.  I'm hoping someone out there knows
> > what the problem is.  Here's the details:
> > 
> > I saw Alfred Perlsteins page on how to setup
> > FreeBSD installs unsing PXE.  
> > The problem I'm having now is when I follow
> Alfred's
> > directions to create the PXE loader (using 4.4R)
> It
> > bombs out.  It's my understanding the I just need
> to
> > stick 'pxeldr' into the root of the TFTP server
> > directory and tell the machine to execute this by
> > specifying it as the boot file in the DHCP
> > configuration.  I also understand that I have to
> > create a subdirectory called 'boot' under the TFTP
> > root directory with the file 'loader.rc' in it. 
> Can
> > someone verify if this is the case?
> > Alfred's instructions can be found here:
> > http://people.freebsd.org/~alfred/pxe/
> > 
> > This is the console output that insues when I try
> and
> > build pxeldr as per Alfred's instructions:
> 
> You need pxeboot (not pxeldr, pxeldr is part of
> pxeboot).  Do you have the
> sources for libstand (src/lib/libstand) installed?
> 
> -- 
> 
> John Baldwin <[EMAIL PROTECTED]> --
> http://www.FreeBSD.org/~jhb/
> PGP Key: http://www.baldwin.cx/~john/pgpkey.asc
> "Power Users Use the Power to Serve!"  - 
http://www.FreeBSD.org/ 

http://briefcase.yahoo.com.au - Yahoo! Briefcase
- Manage your files online.

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: Changing syscalls numbers

2001-10-31 Thread Evan Sarmiento

Did you type make init_sysent.c, after editing syscalls.master?

- Evan

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Changing syscalls numbers

2001-10-31 Thread Nickolay A.Kritsky

  Hi, freebsd-hackers.

Recently I was trying to change some syscalls numbers (i.e. syscall
exit would have number 5 and syscall open would have number 1).
My thought was, that for that operation one must edit file
/usr/src/sys/kern/syscalls.master and remake world. I edited the file
named above, rebooted in single-user mode, and ran "make buildworld &&
make buildkernel && make installkernel && make installworld".
Everything seems to be OK, new kernel has been built and installed (I
think it is `new', because /kernel has the creation date of "make
installkernel" and diff says it differs from /kernel.old ), but
mov eax,1
push eax
int 80h

still performs exit.

Could you point me, what wrong assumptions/steps have I done?
Any help is very good.

PS: please cc me in your reply, as I am not subscriber of this list,
or reply directly to me, if you consider this thread OT.
;---
; NKritsky
; SysAdmin InternetHelp.Ru
; http://www.internethelp.ru
; mailto:[EMAIL PROTECTED]



To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: debugging question

2001-10-31 Thread Mark Santcroos

Ah great. Thanks alot!

Mark

On Wed, Oct 31, 2001 at 01:11:07AM -0800, Julian Elischer wrote:
> Mark Santcroos wrote:
> > 
> > Thats what I already said in my email :)
> > 
> > I was hoping that there is some way to dump the codepath of the kernel.
> > 
> > Or is it maybe possible from ddb to move the context of a certain process
> > and trace from there?
> 
> tr PID
> gives you teh stack of that PID
> 
> then set a breakpoint in a location that you know it will go through
> (e.g. one of the return addresses given in the trace) and then 
> continue.
> 
> > 
> > Mark
> > 
> > ps. I have narrowed it down already a bit more and hope to come with a bug
> > report on -current in the coming days.
> > 
> > On Tue, Oct 30, 2001 at 03:38:45PM -0800, Julian Elischer wrote:
> > > when the system is looping, hit 
> > > to drop into the debugger.
> > >
> > > On Tue, 30 Oct 2001, Andrew R. Reiter wrote:
> > >
> > > > On Tue, 30 Oct 2001, Mark Santcroos wrote:
> > > >
> > > > :How can I see in what piece of the kernel it is looping?
> > > > :(I know about where it is, but not exactly)
> > > > :
> > > >
> > > > Use ddb to set a break -- you may need to do this upon boot (boot -d)
> > > >
> > > > *-.
> > > > | Andrew R. Reiter
> > > > | [EMAIL PROTECTED]
> > > > | "It requires a very unusual mind
> > > > |   to undertake the analysis of the obvious" -- A.N. Whitehead
> > > >
> > > >
> > > > To Unsubscribe: send mail to [EMAIL PROTECTED]
> > > > with "unsubscribe freebsd-hackers" in the body of the message
> > > >
> > >
> > >
> > > To Unsubscribe: send mail to [EMAIL PROTECTED]
> > > with "unsubscribe freebsd-hackers" in the body of the message
> > 
> > --
> > Mark Santcroos  RIPE Network Coordination Centre
> > http://www.ripe.net/home/mark/  New Projects Group/TTM
> > 
> > To Unsubscribe: send mail to [EMAIL PROTECTED]
> > with "unsubscribe freebsd-hackers" in the body of the message
> 
> -- 
> ++   __ _  __
> |   __--_|\  Julian Elischer |   \ U \/ / hard at work in 
> |  /   \ [EMAIL PROTECTED] +-->x   USA\ a very strange
> | (   OZ)\___   ___ | country !
> +- X_.---._/presently in San Francisco   \_/   \\
>   v
> 
> To Unsubscribe: send mail to [EMAIL PROTECTED]
> with "unsubscribe freebsd-hackers" in the body of the message

-- 
Mark Santcroos  RIPE Network Coordination Centre
http://www.ripe.net/home/mark/  New Projects Group/TTM

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: debugging question

2001-10-31 Thread Julian Elischer

Mark Santcroos wrote:
> 
> Thats what I already said in my email :)
> 
> I was hoping that there is some way to dump the codepath of the kernel.
> 
> Or is it maybe possible from ddb to move the context of a certain process
> and trace from there?

tr PID
gives you teh stack of that PID

then set a breakpoint in a location that you know it will go through
(e.g. one of the return addresses given in the trace) and then 
continue.

> 
> Mark
> 
> ps. I have narrowed it down already a bit more and hope to come with a bug
> report on -current in the coming days.
> 
> On Tue, Oct 30, 2001 at 03:38:45PM -0800, Julian Elischer wrote:
> > when the system is looping, hit 
> > to drop into the debugger.
> >
> > On Tue, 30 Oct 2001, Andrew R. Reiter wrote:
> >
> > > On Tue, 30 Oct 2001, Mark Santcroos wrote:
> > >
> > > :How can I see in what piece of the kernel it is looping?
> > > :(I know about where it is, but not exactly)
> > > :
> > >
> > > Use ddb to set a break -- you may need to do this upon boot (boot -d)
> > >
> > > *-.
> > > | Andrew R. Reiter
> > > | [EMAIL PROTECTED]
> > > | "It requires a very unusual mind
> > > |   to undertake the analysis of the obvious" -- A.N. Whitehead
> > >
> > >
> > > To Unsubscribe: send mail to [EMAIL PROTECTED]
> > > with "unsubscribe freebsd-hackers" in the body of the message
> > >
> >
> >
> > To Unsubscribe: send mail to [EMAIL PROTECTED]
> > with "unsubscribe freebsd-hackers" in the body of the message
> 
> --
> Mark Santcroos  RIPE Network Coordination Centre
> http://www.ripe.net/home/mark/  New Projects Group/TTM
> 
> To Unsubscribe: send mail to [EMAIL PROTECTED]
> with "unsubscribe freebsd-hackers" in the body of the message

-- 
++   __ _  __
|   __--_|\  Julian Elischer |   \ U \/ / hard at work in 
|  /   \ [EMAIL PROTECTED] +-->x   USA\ a very strange
| (   OZ)\___   ___ | country !
+- X_.---._/presently in San Francisco   \_/   \\
  v

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



Re: /etc/ld.so.preload?

2001-10-31 Thread Lamont Granquist


Sorry, that one isn't backwards compatible with the present version of
the hints file.  This one behaves nicer.

On Tue, 30 Oct 2001, Lamont Granquist wrote:
> Well, here's a short patch to add the necessarily functionality to
> /var/run/ld-elf.so.hints and /usr/libexec/ld-elf.so.1.  If this is
> acceptable, /sbin/ldconfig would need to be patched.
>
> Looks like the major bug is that if you preload libraries globally you
> break linux binary compatibility.
>
> On Tue, 30 Oct 2001, Lamont Granquist wrote:
> > Is there anything in FreeBSD that gives this functionality?  My reading of
> > src/libexec/rtld-elf/rtld.c in both -stable and -current seems to indicate
> > that there isn't any such functionality (i need the global functionality
> > that LD_PRELOAD doesn't give me).  I'd be willing to write a patch for it,
> > but I'd need some guidance on what would be a proper way to fix it.
> >
> > I'm thinking of a patch to ldconfig to get /etc/ld.so.preload into the
> > hints file and then to hack gethints() in rtld.c to take an argument
> > indicating which path you want to return.
> >
> >
> >
> > To Unsubscribe: send mail to [EMAIL PROTECTED]
> > with "unsubscribe freebsd-hackers" in the body of the message
> >
> >
>


--- libexec/rtld-elf/rtld.c~Tue Oct 30 18:28:00 2001
+++ libexec/rtld-elf/rtld.c Wed Oct 31 00:55:05 2001
@@ -52,8 +52,10 @@
 #include "debug.h"
 #include "rtld.h"
 
-#define END_SYM"_end"
-#define PATH_RTLD  "/usr/libexec/ld-elf.so.1"
+#define END_SYM"_end"
+#define PATH_RTLD  "/usr/libexec/ld-elf.so.1"
+#define HINT_LIBRARY_PATH  0x01
+#define HINT_PRELOAD   0x02
 
 /* Types. */
 typedef void (*func_ptr_type)();
@@ -80,7 +82,7 @@
 static void errmsg_restore(char *);
 static char *errmsg_save(void);
 static char *find_library(const char *, const Obj_Entry *);
-static const char *gethints(void);
+static char *gethints(int);
 static void init_dag(Obj_Entry *);
 static void init_dag1(Obj_Entry *root, Obj_Entry *obj, DoneList *);
 static void init_rtld(caddr_t);
@@ -91,7 +93,7 @@
 static void linkmap_add(Obj_Entry *);
 static void linkmap_delete(Obj_Entry *);
 static int load_needed_objects(Obj_Entry *);
-static int load_preload_objects(void);
+static int load_preload_objects(char *);
 static Obj_Entry *load_object(char *);
 static void lock_check(void);
 static Obj_Entry *obj_from_addr(const void *);
@@ -359,7 +361,9 @@
 sym_zero.st_shndx = SHN_ABS;
 
 dbg("loading LD_PRELOAD libraries");
-if (load_preload_objects() == -1)
+if (load_preload_objects(ld_preload) == -1)
+   die();
+if (load_preload_objects(gethints(HINT_PRELOAD)) == -1)
die();
 preload_tail = obj_tail;
 
@@ -805,7 +809,7 @@
 if ((refobj != NULL &&
   (pathname = search_library_path(name, refobj->rpath)) != NULL) ||
   (pathname = search_library_path(name, ld_library_path)) != NULL ||
-  (pathname = search_library_path(name, gethints())) != NULL ||
+  (pathname = search_library_path(name, gethints(HINT_LIBRARY_PATH))) != NULL ||
   (pathname = search_library_path(name, STANDARD_LIBRARY_PATH)) != NULL)
return pathname;
 
@@ -873,38 +877,54 @@
  * necessary.  Returns NULL if there are problems with the hints file,
  * or if the search path there is empty.
  */
-static const char *
-gethints(void)
+static char *
+gethints(int hintflag)
 {
-static char *hints;
+static char *preload;
+static char *library_path;
 
-if (hints == NULL) {
+if ((library_path == NULL) || (preload == NULL)) {
int fd;
struct elfhints_hdr hdr;
char *p;
 
/* Keep from trying again in case the hints file is bad. */
-   hints = "";
+   library_path = "";
+   preload = "";
 
if ((fd = open(_PATH_ELF_HINTS, O_RDONLY)) == -1)
return NULL;
if (read(fd, &hdr, sizeof hdr) != sizeof hdr ||
  hdr.magic != ELFHINTS_MAGIC ||
  hdr.version != 1) {
-   close(fd);
-   return NULL;
+   goto cleanup;
}
p = xmalloc(hdr.dirlistlen + 1);
if (lseek(fd, hdr.strtab + hdr.dirlist, SEEK_SET) == -1 ||
  read(fd, p, h

Re: Test Suites

2001-10-31 Thread Terry Lambert

Sergey Babkin wrote:
> > Look also for "TET" and "ETET".  SVVS (the System V Verification
> > Suite, used for testing SVID compliance) uses TET.
> 
> TET is owned by the Open Group and they license it for money
> (at least they did a couple of years ago). It's also a pain
> to use.

I saved the public TET and ETET implementations, as well as the
draft Sepc 1170, and a number of other important documents when
UNIX International went under.

The documents were generaously hosted on the Digiboard FTP site.

There are currently freeware versions of these documents and code
floating around.  I _know_ there is a TET 3.x around, since I
have it on an old machine in the other room.

-- Terry

To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message



subscribe

2001-10-31 Thread Wency Arzadon


--- include/elf-hints.h~Tue Oct 30 18:29:57 2001
+++ include/elf-hints.h Tue Oct 30 18:31:47 2001
@@ -40,7 +40,10 @@
u_int32_t   dirlist;/* Offset of directory list in
   string table */
u_int32_t   dirlistlen; /* strlen(dirlist) */
-   u_int32_t   spare[26];  /* Room for expansion */
+   u_int32_t   preloadlist;/* Offset of preload list in 
+  string table */
+   u_int32_t   preloadlistlen; /* strlen(preloadlist) */
+   u_int32_t   spare[24];  /* Room for expansion */
 };
 
 #define ELFHINTS_MAGIC 0x746e6845
-- 



To Unsubscribe: send mail to [EMAIL PROTECTED]
with "unsubscribe freebsd-hackers" in the body of the message